function auto_gen_seg

%auto-x-section-segmentation function here.  this function will
%automatically detect and segment the x-section from the background. the
%resulting segmented image (containg the proposed x-section) will be passed
%on to the user interactive part of the x-section segmenation codes.  if
%the segmentation methods contained in this function fail to accurately
%segment the x-section then the user can manually perform this action in
%the next step.

%note: this method may be augmented in the future with some scripts aimed at
%reducing background noise while performing image contrast enhancements applied
%only to this function of the program.

global img1 solidSegment finalIM;


%steps for x-section segmentation:
    
%--1--: convert to binary image using otsu's method.
    
%--2--: convert binary image to negative.
    
%--3--: dilate image negative.
    
%--4--: fill dilated image.
    
%--5--: clear any objects touching image border.
        
%--6--: erode perimeter pixels of largest object. 
    
%--7--: find largest object in image (this should be the x-section).
                %keep only largest object in binary image.
          
%--8--: segment original image.


    
    
    
%description of step 1:
    
%using otsu's method, define the pixel value threshold for converting a 
%gray-scale image to a black/white binary image. all pixel values greater 
%than or equal to the 'threshold' will be converted to white [pixel value = 255]
%and all pixel values less than the threshold will be converted to black 
%pixels [pixel value = 0]. 

    
imBinary = imcomplement(im2bw(img1, graythresh(img1)));
                                       
                                           
%description of step 2:
    
%to seal up any breaks/holes in object structures the image pixels must
%be dilated.  image dilation is performed only on image pixels of value
%= 1 (white piels).  since structure pixels have a pixel value = 0 
%(black pixels) we must make an image negative/complement.
                                            

%description of step 3:
    
%dilate the image negative to seal up any breaks/holes around object
%perimeter regions.   this will ensure that all pixels for each object
%are included the steps leading to x-section segmentation.

%create structural elements for image dilation.

%1st-structural element.  

sedisk          = strel('disk', 6); 
 
imDil = imdilate(imBinary, sedisk);  
    

    
%description of step 4:

%these types of binary images have holes, representing cell area pixels
%that are of significance to this program, that need to be included with
%the x-section object. to include these pixels (holes), one must fill
%them. auto-fill dilated image using the 'holes' option.  this will make each 
%image object solid so all object pixels (i.e. cell strcuture and cell
%area) are use in indexing. 
    
imFill = imfill(imDil, 'holes');
    

%description of step 5:
    
%since root-sectioners were instructed to make sure each x-section image
%is centered in the image, no x-section objects should be touching
%any image border.  even if x-section objects touch the image border 
%they can not be used since the pixel data is incomplete.  sometimes,
%entire x-sections are touching other objects that directly touch image
%border and are removed.  if this happens, the user can manually
%segment the image in the next step.
    
%clear all objects from image border.

clearborder = imclearborder(imFill, 4); 


%if the xs segment was cleared then run an additional script to recover it.

switch (bwarea(clearborder) < .1*bwarea(imFill))
        
	case 1
          
        
        %erode the solid binary image.
        
    	imFill       = imerode(imFill, sedisk); 
        
        
        %set all 1st and last 7 rows of pixels equal to 1.
        
        imFill([(1:7) ((end-6):end)],:)    = 1; 
        
        
        %set all 1st and last 7 columns of pixels equal to 1.

        imFill(:, [(1:7) ((end-6):end)])   = 1;
        
        
        %clear the image border now.
        
        clearborder = imclearborder(imFill, 4);
        
        
        %dilate the image again.
        
        clearborder = imdilate(clearborder, sedisk);
            
end;
    
        
    
%description of step 6:
    
%previously dilated x-section object, includes non-x-section pixels adjacent
%to object perimeter boundary.  these pixels need to be eroe now.   
     


%create structural elements for image erosion.

%erode the image.  

solidSegment = imerode(clearborder, sedisk);  
    
    
    
%description of step 7:
    
%the current image has one or more objects depending on the amount of
%dirt/debris on the microscope slide. the largest object should be the
%image x-section.  select the largest object using the label matrix
%function.  the label matrix function labels all pixels for a particular
%object in a binary image with a double precision number. to find the
%largest object find  the mode of the label matrix, excluding all
%background pixels.
                                                                     
imageLabel               = bwlabel(solidSegment, 8);  

largeObj = mode(double(imageLabel(imageLabel > 0)));  

                                                          
%retain binary pixels for largest object. remove all other objects.                                                

solidSegment(imageLabel == largeObj) = 1; %keep largest object.
solidSegment(imageLabel ~= largeObj) = 0; %remove other objects.
        
    
    
%after eroding solid binary x-section. more than 1 one object may remain as
%a result of the erosion.  we need to eliminate all other objects.


%create label matrix.

imageLabel              = bwlabel(solidSegment, 8);  


%find the largest object pixel indices in label matrix.

largeObj = mode(double(imageLabel(imageLabel > 0)));  


%retain binary pixels for largest object. remove all other objects.                                                

solidSegment(:)                     = false; %remove all objects.
solidSegment(imageLabel == largeObj) = true; %keep largest object.
    
    
%DESCRIPTION OF STEP 8:
    
%segment the grayscale image containing the x-section using the largest
%object pixel indices.  we sholud have a grayscale image containing
%only the x-section pixels. all other pixels are backghround pixels
%(i.e. they are white).

    
finalIM                             = (img1*0) + 255;  %define blank x-section grayscale
finalIM(solidSegment ~= 0) = img1(solidSegment ~= 0);  %place x-section pixels in the imaGE.




end