function stele_objs = automatic_XV_detection
             
%this function automatically detects the meta xylem objects.

    global     AllImageSpecs; %structure containing all image specifications.
    global       data_matrix; %data matrix.
    global LABEL_STELE_AREAS; %lable matrix for stele area objects.
    global              Coms; %x-section center of mass coordinates
    global          X_binary; %binary x-section image.
    global      solidSegment; %solid x-section image.
    global     get_ref_cdata; %reference image cdata.
    global      ref_axes_obj; %reference image axes handle.
    global     main_axes_obj; %main image axes handle.        



    %create stele binary image from x-section binary image already defined at 
    %the beginning of phase 3 in the main program.

    steleBinary           = X_binary;


    %erase all non-stele area pixels.  you should only have stele
    %cell area pixels being white (i.e. true).

    steleBinary(solidSegment == 0) = 1;





    %----------------start xylem vessel detection algorithm-------------------%







    %create the label matrix for the local_map_stele variable derived in
    %the local threshold module. 

    LABEL_STELE_AREAS = bwlabel(steleBinary, 4);  


    %find object properties of stele region. 

    labelStelObjs = regionprops(LABEL_STELE_AREAS, 'Area', 'Perimeter', ...
        'Centroid', 'MajorAxisLength', 'MinorAxisLength');


    %concatenate object properties into a column matrix.

    ConcatSteleObjs = horzcat((1:max(max(LABEL_STELE_AREAS)))', ...
        cat(1,labelStelObjs.Area), cat(1,labelStelObjs.Perimeter), ...   
        cat(1,labelStelObjs.MajorAxisLength), ...
        cat(1,labelStelObjs.MinorAxisLength), cat(1,labelStelObjs.Centroid), ...
        (1:max(max(LABEL_STELE_AREAS)))'*0);


    ConcatSteleObjs(1,:) = [];

    %calculate the x and y coordinates for all stele region objects using the 
    %cross-section center of mass.

    ConcatSteleObjs(:,6) = ConcatSteleObjs(:,6) - Coms(1); 
    ConcatSteleObjs(:,7) = ConcatSteleObjs(:,7) - Coms(2);


    %calculate the angle and radii of all stele objects using matlabs:
    %'cart2pol' function.

    [theta, rho] = cart2pol(ConcatSteleObjs(:,6), ConcatSteleObjs(:,7));


    theta(theta <= 0) = theta(theta <= 0) + 2*pi;



    %fill in the applicable data matrix columns with the angle and radii of all
    %stele objects.

    ConcatSteleObjs(:,6) = theta;
    ConcatSteleObjs(:,7)   = rho;



    %sort the matrix by object area. retain everything but the background 
    %(which is considered an object).

    ConcatSteleObjs = sortrows(ConcatSteleObjs, 2); 


    %define a buffer bounding box around the centroid coordinates. 

    defineObjs = LABEL_STELE_AREAS(floor(Coms(2)) +  (-4:4), floor(Coms(1)) + (-4:4));   


    %remove the zeros from the selection. the zeros represented tissue.  
    %that is not included with this calculation.

    defineObjs = defineObjs(defineObjs ~= 0);  


    %remove objects in the center of stele.


    %find the objects contained in the buffer bounding box that intersect
    %with the object properties matrix.

    memberObj = ismember(ConcatSteleObjs(:,1), defineObjs);  


    %index them according to place in matrix.

    memberObj = abs(memberObj - 1);  


    %flag the objects.
    %remove the flagged objects from the object properies matrix.

    ConcatSteleObjs(memberObj == 0,:)                       = 0;  
    stele_objs   = ConcatSteleObjs(ConcatSteleObjs(:,1) ~= 0,:);  


    %calculate the differential of ranked object areas.  this gives us
    %a linear diliniation between cells and xylem vessels.

    differential = [0; (stele_objs(2:end,2) - stele_objs(1:end-1,2))];   


    %January 24, 2011: there was problem with the xylem vessel
    %detection algorithm.  There are some areas counted as xylem
    %vessels when they are not.  This is due to the previous
    %calcualation of the 'mean' and 'std' of the ranked area differential 
    %vector. All stele region objects with area greater than the 'mean' 
    %+ 'std' are considered xylem vessels.  This is not an accurate way
    %for detecting xylem vessels since there can be a large variation
    %in stele object sizes throughout the stele.  Therefore, as stated
    %before, this method included smaller objects that were not xylem
    %vessels.  The new method ranks the xylem vessel sizes in
    %increasing order, caculates the rank size differential and finds
    %the largest differential in rank vector.  This largest
    %differential is the cutoff point between xylem vessels and other
    %objects since xylem vessels are the largest objects in the stele
    %region.  

    %A test was performed on the old and new method to determine if the
    %automated detection method has improved.  The results from the two
    %methods were tested using a 2-sample t-test and it was determined
    %that they are significantly different (alpha=.05, p = 1.276e-14).
    %It was shown that method 1 over-estimates the xylem vessel sizes
    %more than method 2.  Method 2, however, provides an underesimate
    %from time to time but this under-estimate is not significant in
    %terms of the the number mouse clicks required to select any
    %undected xylem vessel.  Therefore, method 2 reduces the amount of
    %user interactive and increases runtime efficiency.


    %See new method on the next two lines.


    %find the maximum differential.  this will give us the lower cutoff
    %point for xylem vessel sizes since xylem vessels are nomally the
    %largest pixel objects in the stele regions.

    find_low_index = find(differential == max(differential));



    %determine were the object size cutoff is for the meta-xylem using a bi-modal
    %variance minimization.

    switch isempty(stele_objs)

        case 1

        	stele_objs = ConcatSteleObjs;

    end;


    %define the size threshold between the meta xylem vessels and and other objects.

    midpoint               = auto_meta_detect(stele_objs(:,2));

    
    %keep all object data whose area is above the midpoint.
    
    larger_objects = stele_objs(stele_objs(:,2) >= midpoint,:);


    %compare the results from the two meta-xylem detection methods using the
    %ismember function.  the is a binary vector of size highlight_stele_objs(:,1).  a
    %value of 1 signifies a match while a 0 shows a non-match.

    compare_xv_detect_kmeans       = ismember(stele_objs(:,1), larger_objects(:,1));

    compare_xv_detect = ismember(stele_objs(:,1), stele_objs(find_low_index:end,1));


    %compute joint membership.  multiply both member results.  

    compare = compare_xv_detect.*compare_xv_detect_kmeans;


    %label those stele region objects as meta xylem if they meet both
    %membership requirements as stated above.

    stele_objs(compare == 1,end) = 2;



    %define pathway to current coded x-xection image.  this image is located
    %in the temporary image directory (temp) inside the current parent image directory.

    imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'XsectionCode.tif'];


    %read in temporary image from temp directory.

    XsectionCode = imread(imagename);




    %if the automated options for xylem vessel detection are turned on then record
    %the data now.

    switch (AllImageSpecs.automated_settings(5)*AllImageSpecs.automated_settings(end) == 1) 

        case 1


        %detect proto-xylem vessel object using my defined function:
        %'proto_xylem'.

        stele_objs = automatic_protoXV_detection(stele_objs);


        %xv_tags defined here. value = 1 --> proto xylem vessels.  value = 2
        %--> meta xylem vessels.

        xv_group = [2 1];


        %define stele region with highlighted xylem vessels.

        highlight_stele_objs = ones(size(steleBinary), 'uint8')*255;  
        highlight_stele_objs(steleBinary == 0)                  = 0;


        for xv = 1:2;


            %calculate the xylem vessel area.

            xv_data = highlight_stele_objs(stele_objs(:,end) == xv_group(xv),:);

            xv_area       = sum(xv_data(:,2))/(AllImageSpecs.calib_area);  


            %count the number of xylem vessles by finding the length of xv_data.

            num_XV = size(xv_data,1); 


            %define the major and minor axis lengths for the xylem vessel objects.
            %these axis values will be used for the xylem vessel diameter statistics.                                     

            major_axis_length = xv_data(:,4); 
            minor_axis_length = xv_data(:,5); 

            major_minor_AL = horzcat(major_axis_length, minor_axis_length);

            
            %find the mean of the minor and major object axes.  we will use
            %this value to calculate the mean stele diameter.
            
            mean_major_minor_AL                  = mean(major_minor_AL, 2);


            %median xylem vessel diameter.

            med_xv_diam = median(mean_major_minor_AL)/(AllImageSpecs.calib_length);


            %standard deviation of xylem vessel diameters.

            std_xv_diam = std(mean_major_minor_AL)/(AllImageSpecs.calib_length);


            %smallest xylem vessel diameter.

            low_xv_diam = min(mean_major_minor_AL)/(AllImageSpecs.calib_length);


            %largest xylem vessel diameter.

            high_xv_diam = max(mean_major_minor_AL)/(AllImageSpecs.calib_length);



            %calculate the median, std, low and high xvlem vessel areas.


            %median xylem vessel area.

            med_xv = median(xv_data(:,2))/AllImageSpecs.calib_area;


            %standard deviation of xylem vessel areas.

            std_xv    = std(xv_data(:,2))/AllImageSpecs.calib_area;


            %smallest xylem vessel area.

            low_xv    = min(xv_data(:,2))/AllImageSpecs.calib_area;


            %largest xylem vessel area.

            high_xv   = max(xv_data(:,2))/AllImageSpecs.calib_area;


            %calculate the 'r^4' term in the total water flux calculation using 
            %Poiseuille's equation.


            %calculate radius of each xylem vessel object (i.e. the mean of the major
            %and minor axis lengths).

            xylem_vessel_radii = (1/1000)*(mean_major_minor_AL/2)/AllImageSpecs.calib_area;


            %sum these r^4 terms up.

            total_xv_r4power = sum(xylem_vessel_radii.^4);




            switch xv

                case 1


                %place the meta xv data in global data matrix.

                data_matrix{DirSpecs.iteration, 24}           = num_XV; %# of meta-xv.
                data_matrix{DirSpecs.iteration, 25}           = med_xv; %median meta-xv area.
                data_matrix{DirSpecs.iteration, 26}           = std_xv; %std meta-xv area.
                data_matrix{DirSpecs.iteration, 27}           = low_xv; %low meta-xv area.
                data_matrix{DirSpecs.iteration, 28}          = high_xv; %high meta-xv area.
                data_matrix{DirSpecs.iteration, 29}      = med_xv_diam; %median meta-xv diameter.
                data_matrix{DirSpecs.iteration, 30}      = std_xv_diam; %std meta-xv diameter.
                data_matrix{DirSpecs.iteration, 31}      = low_xv_diam; %low meta-xv diameter.
                data_matrix{DirSpecs.iteration, 32}     = high_xv_diam; %high meta-xv diameter.
                data_matrix{DirSpecs.iteration, 33}          = xv_area; %meta-xv area.

                data_matrix{DirSpecs.iteration, 34} = total_xv_r4power; %r^4 h2o conductance.


                case 2


                %place the proto xv data in global data matrix.    

                data_matrix{DirSpecs.iteration, 35}           = num_XV; %# of proto-xv.
                data_matrix{DirSpecs.iteration, 36}           = med_xv; %median proto-xv area.
                data_matrix{DirSpecs.iteration, 37}           = std_xv; %std proto-xv area.
                data_matrix{DirSpecs.iteration, 38}           = low_xv; %low proto-xv area.
                data_matrix{DirSpecs.iteration, 39}          = high_xv; %high proto-xv area.
                data_matrix{DirSpecs.iteration, 40}      = med_xv_diam; %median proto-xv diameter.
                data_matrix{DirSpecs.iteration, 41}      = std_xv_diam; %std proto-xv diameter.
                data_matrix{DirSpecs.iteration, 42}      = low_xv_diam; %low proto-xv diameter.
                data_matrix{DirSpecs.iteration, 43}     = high_xv_diam; %high proto-xv diameter.
                data_matrix{DirSpecs.iteration, 44}          = xv_area; %proto-xv area.

                data_matrix{DirSpecs.iteration, 45} = total_xv_r4power; %r^4 h2o conductance. 

            end;




            %visual analysis: display highlighted xylem vessels.



            %run for loop for previously defined xylem vessle objects. color those
            %objects now.

            if (isempty(xv_data(:,1)) == 0)  


                %loop through all object indexes.

                for obj_i = 1:length(xv_data(:,1))  


                    %asign color code to all xylem vessel object index pixels.

                    highlight_stele_objs(LABEL_STELE_AREAS == xv_data(obj_i,1)) = AllImageSpecs.highlightCode(xv+1);  

                end;


            end;


            %place xylem vessel pixels in XsectionCode.

            XsectionCode(highlight_stele_objs == AllImageSpecs.highlightCode(xv+1)) ...
                = AllImageSpecs.highlightCode(xv+1);         


            %find the current highlighted xv objects (meta or proto, depends on which
            %objects are in focus).



        index = find(highlight_stele_objs == AllImageSpecs.highlightCode(xv+1));



        %assign highlight to red channel.

        get_ref_cdata(index)                                    = AllImageSpecs.refColors(xv+1,1);


        %assign perimeter highlight to green channel.

        get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   = AllImageSpecs.refColors(xv+1,2);


        %assign perimeter highlight to blue channel.

        get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) = AllImageSpecs.refColors(xv+1,3);


        end;



        %save the coded image now.

        imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
            AllImageSpecs.fileSeparator 'XsectionCode.tif'];  

        imwrite(XsectionCode, imagename, 'tif');  


        %set the current highlighted xylem vessel image to the cdata properties
        %of the main image axes.

        set(main_axes_obj, 'cdata', highlight_stele_objs); 



        %set the current reference image to the cdata properties of the
        %reference image axes.

        set(ref_axes_obj, 'cdata', get_ref_cdata);



    end;






              
end