function cortexData = automatic_lacunae_detection(XsectionCode)

%automated aerenchyma detection here: during this step the attributes are
%cortex object attributes are collected from each object.  object
%attributes consist of: area, centroid, perimeter, major_axis_length and
%equivalent diameter.  only locational and area data are used to determine
%which cortex objects are aerenchyma.  the other attributes were just left
%in the data matrix.  they may be useful in the future.


global            Coms; %x-section center of mass coordinates.
global        X_binary; %x-section binary image.
global    solidSegment; %solid stele image
global              L4; %label matrix for cortical objects.
global   AllImageSpecs; %structure containing image specifications.

    

           %--------CORTEX FOR AERENCHYMA MEASUREMENTS--------%
        


    %create dummy binary X-section image so we do not overwrite the real binary
    %x-section image. call the image X_binary2.

    X_binary2                = X_binary;
    
    
    %blacken out stele area and lateral area.  all you should have left is a binary image
    %containing only cortical cells being white (i.e. true).

    X_binary2(solidSegment ~= 0)                                   = 0;
    X_binary2(XsectionCode == AllImageSpecs.highlightCode(6))      = 0;

    
    
    %label all cell area objects in cortical region using function:
    %bwlabel.
    
    [L4, num_cortex_objs] = bwlabel(X_binary2, 4);
    

    
    
    %calculate the attributes of the cortex binary using the 'regionprops'
    %function.
    
    L4_regionprops = regionprops(L4, 'Area', 'Centroid', ...
        'Perimeter', 'MajorAxisLength', 'MinorAxisLength');
    
    
    %allocate matrix.
    
    cortexData = zeros(num_cortex_objs,11);
    
    
    %place variables in matrix.
    
    cent      = cat(1, L4_regionprops.Centroid);
    
    cortexData(:,1)             = cat(1, L4_regionprops.Area);
    cortexData(:,2)                   = (1:1:(max(max(L4))))';
    cortexData(:,5)                     = cent(:,1) - Coms(1);
    cortexData(:,6)                     = cent(:,2) - Coms(2);    
    
    [theta, rho] = cart2pol(cortexData(:,5), cortexData(:,6));
    theta(theta < 0)                = theta(theta < 0) + 2*pi;
    
    cortexData(:,3:4)                           = [theta rho];
    cortexData(:,7)  = cat(1, L4_regionprops.MajorAxisLength);
    cortexData(:,8)                                     = rho;
    cortexData(:,9)  = cat(1, L4_regionprops.MinorAxisLength);
    
    
    
    %remove the background object.
    
    cortexData(cortexData(:,2) == 1, :) = [];
    
            
    %label background in label matrix -1.
    
    L4(L4 == 1)           = -1;
    L4(solidSegment ~= 0) = -1;
    
    
    
    
    %clear some variables from memory.

    clear L4_regionprops cent theta rho;
    
    
    
                        
    %remove data associated with the background and stele regions.
    
    %remove all data associated with image background.
    
    cortexData(cortexData(:,2) == 1, :) = [];
    
    
    %remove all data associated with stele region.
       
    cortexData    = sortrows(cortexData, -1);
                           
                         
    %make adjustments to the radius from the centroid %by referencing data via. 
    %theta slices.  the radii are now normalized radii according to
    %relative position between the inner and outer cortical structure
    %boundary.  this will be run in a separate function.
    
    cortexData = cort_obj_norm(cortexData);
    



    %write noise filter for cortex region objects.  This noise filter
    %will attempt to distinguish between noise objects (i.e. image artifacts and 
    %intercellular space) and general cortex objects (i.e. cortex cells
    %and aerenchyma lacunae).
                

    %filter out cortex noise now.
    
    %classify all cortex objects with either the major axis length or
    %minor axis length equal to 2 as cortex noise.  assign code value = -2 to
    %object (i.e. assign a -2 to data column 5 for all noise objects).


    %define code value assignment for all objects qualifying under the rule for
    %major axis length standard.

    cortexData(cortexData(:,7) < 2, 10) = -2;


    %define code value assignment for all objects qualifying under the rule for
    %minor axis length standard.

    cortexData(cortexData(:,9) < 2, 10) = -2;

        
    %consider only those non-noise objects in the auto-aerenchyma detection script.
                
    non_noise = cortexData(cortexData(:,10) ~= -2,:);
        
                          
    %remove all normlized radii falling outside the target range for 
    %aerenchyma.  this value was determined experimentally to be:
                         
    %lower bound --> .4 - .2 = .2
    %upper bound --> .4 + .2 = .6
                         
    non_noise((non_noise(:, 4) >= .2) & (non_noise(:, 4)  <= .6),10) = 1;
                         
                         
    subRadRange = non_noise(non_noise(:,10) == 1, :);
                         
        
    %additionally, select only those areas that have a major axis length greater than
    %the mean + std.
        
    meanStdMajorAx = median(subRadRange(:, 7)) + ...
        std(subRadRange(:, 7));
                         
    indexs = subRadRange((subRadRange(:,7) >= ...
        meanStdMajorAx), 2);  
                         
      
    %index these results into the cortical object data matrix formed at the
    %beginning of the function.
    
    for J = 1:length(indexs)
                             
        non_noise(non_noise(:,2) == indexs(J), 10) = 2;
                             
    end;
                         
     
    %define aerenchyma areas for noise filtering.
    
    aerenchyma = non_noise(non_noise(:,10) == 2, 2);

    
    %define those object that are not noise and that could be aerenchyma.
    
    non_noise_member = ismember(cortexData(:,2), aerenchyma);    
    
    cortexData(non_noise_member == 1,10) = 2;
        
    
    %sort cortex object attributes by cortex object size.
        
    cortexData = sortrows(cortexData, 1);
        


    
end