function automatic_stele_segmentation

%this function automatically detects stele using a variety of mathematical 
%and statistical manipulations to the image pixel map.

global   AllImageSpecs; %image specifications.
global    solidSegment; %solid segment image.
global repRows repCols; %row and column indice matrices.
global            Coms; %x-section center of mass coordinates.    
        
        
%load in temporary images used for this step.
        
imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
	AllImageSpecs.fileSeparator 'current_image.' AllImageSpecs.format];
        
current_image                        = imread(imagename);  
        
        
%define XsectionCode image.  this image initially contains the coded
%cross-section and lateral (if any). this temporary image will be
%trimmed down to only contain the stele region at the functions end.  
%this image will not be saved again.  therefore, image var-name will 
%be used multiple times thorughout this function.
        
imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
    AllImageSpecs.fileSeparator 'XsectionCode.tif'];
        
XsectionCode                        = imread(imagename);  
        

%convert to double precision for calculations.

XsectionCode   = double(XsectionCode); 

        
%determine if a lateral is present in the current image.
        
IsLat = isempty(XsectionCode(XsectionCode == AllImageSpecs.highlightCode(6)));
        
        
%define the x-section pixels in XsectionCode.
        
XsectionCode(XsectionCode ~= 0) = 255;
        

%first step: radially truncate x-section to retain only stele and
%partial inner cortex regions.
        

%-------------------CALCULATE THE SPATIAL WEIGHT MATRIX-------------------%
        
%define the distance matrix based on the cross section center of mass.
        
distance = sqrt((repCols - Coms(1)).^2  + (repRows - Coms(2)).^2);

%define the band width map for the spatial matrix.   the bandwidth parameter
%is not a single averaged number anymore.  it is a bandwidth map since each
%cross section has a degree of assymetry.
        
bandVect = calcBand(XsectionCode);
        
        
%define spatial weights matrix for the elimination of the outer cortex since
%some regions in the outer cortex are much darker and could be retained in the
%stele region by accident.
        
radial_truncation            = (1 - ((distance./(.9*bandVect)).^2).^2);

        
%since the spatial weights matrix emphasizes lighter objects we must take the
%compliment of the image to emphasize the darker stele.
        
current_image = imcomplement(current_image);

labelMat = (double(current_image).*radial_truncation);



%remove all pixels whos spatial weight matrix values are less than zero.
        
posLabel = labelMat(labelMat > 0);


%define a rough threshold for stele region.

thresh = median(posLabel) - .5*std(posLabel);
        
    
%use this rough threshold to eliminate more outlier pixels.

current_image(labelMat < thresh) = 0;
        
        
%use the results from the spatial weights matrix for the cross section pixel
%density measurements  -- new function --
        
XsectionCode = calcDens(current_image);
        
     
%remove any debris before completing the stele/cortex segmentation steps.
     
     
%define label matrix for the purpose of removing image debris.
     
labelMat              = bwlabel(XsectionCode,8);

     
%remove every object but the largest object in the label matrix. 


%define the largest object in the label matrix using the mode function.
     
label_mode = mode(double(labelMat(labelMat > 0)));


%remove all other objects except the mode of the label matrix.
          
XsectionCode(labelMat ~= label_mode) = 0;

        
                                
%initialize the final steps in the stele segmentation algorithm.
        
%step 1: define structural element used in the image dilation.
%step 2: dilate the image.
%step 3: fill the image.
%step 4: erode pixels from the resulting filled image based on the
%smoothing function.
    
se                        = strel('disk', 6); %step 1.
 
solidSegment    = imdilate(XsectionCode, se); %step 2.
            
solidSegment = imfill(solidSegment, 'holes'); %step 3.
     
solidSegment     = imerode(solidSegment, se); %step 4.
        
        

%new stele segmentation step.  we are going to smooth the solid stele
%image now to remove the rough edges of the stele perimeter
%resulting from the binarization algorithm.
        
%step 1: calculate the stele region perimeter image. (executed in step 3).
        
%step 2: find the row and column indices for the stele perimeter (excuted in step 3).
        
%step 3: apply smoothing function to stele perimeter.
        
%step 4: remove all non-stele area pixels from the cross-section.
        
        
%these steps are included in the function below.

stpersmooth(IsLat);
        
             
        
end