function cortex_RE_analysis

%this function will reanalyze the cortex cell data with the assumption the
%user changed the cortex cell size noise thresholds.



global AllImageSpecs;
global   data_matrix;
global     directory;
global            L4;
global  solidSegment;



%list the directory containing the main Rootscan functions.

rs_directory                         = which('cortex_RE_analysis.m');

index = find(rs_directory == AllImageSpecs.fileSeparator, 1, 'last');

rs_directory                                 = rs_directory(1:index);



%load filters settings from the Rootscan functions directory.



%load in the cortex cell size interval settings from the Rootscan functions
%directory.


regionvals = load([rs_directory 'INTERVAL_MAT.mat']); 
regionvals                 = struct2cell(regionvals); 


%define interval and tags place them in a structure.

bands_intervals = [0 regionvals{1,1}{1,:}{1,:}]; 

bands_colors    = [0 regionvals{1,1}{1,:}{2,:}];

bands_labels             = regionvals{1,1}{2,1};






%ask the user to select a directory for reanalysis.

directory = uigetdir;



%load the calibration file.

calib_vals  = load([directory  AllImageSpecs.fileSeparator' 'CALIB_MAT.mat']);

calib_area           = calib_vals.calibprecis(1).*calib_vals.calibprecis(2);

calib_length      = (calib_vals.calibprecis(1)+calib_vals.calibprecis(2))/2; 

precision                                       = calib_vals.calibprecis(3); 



%ask the user if they would like to resume where they left off or start
%over.

user_choice = questdlg('Would you like to Resume Current Analysis', ...
    'Resume Progress', 'Yes', 'No', 'Yes');


switch isempty(user_choice)
    
    case 1
        
        user_choice = 'No';
    
end;





%load the x-section center mass coordinates.

temp_exist = exist([directory AllImageSpecs.fileSeparator 'temp'], 'dir');

switch temp_exist
    
    case 7

        Coms = load([directory AllImageSpecs.fileSeparator 'temp' AllImageSpecs.fileSeparator 'XScoms']);
        Coms                                                                         = struct2cell(Coms);
        Coms                                                                                 = Coms{1,1};
        

end;
        
   
temp_exist = exist([directory AllImageSpecs.fileSeparator 'TEMP'], 'dir');


switch temp_exist
    
    case 7

        Coms = load([directory AllImageSpecs.fileSeparator 'TEMP' AllImageSpecs.fileSeparator 'XScoms']);
        Coms                                                                         = struct2cell(Coms);
        Coms                                                                                 = Coms{1,1};

end;

        
        

%load in the data matrix.

data_matrix = load([directory AllImageSpecs.fileSeparator 'DATA_MAT.mat']);
data_matrix                                     = struct2cell(data_matrix);  
data_matrix                                             = data_matrix{1,1};  


%check the data matrix for completeness.

complete_val = data_matrix{end,3};



switch (complete_val ~= -1)
    
        %the directory is completed. proceed with the reanalysis.
    
    case 1


        %determine if Rootscan should resume the current analysis
        %per user discretion.
                       
        
        %ask user to input the name of the output file.

        file_name = inputdlg('Input filename of reanalyzed cortex data', ...
        	'Name File');

        file_name = cell2mat(file_name);
        
        
        
        switch user_choice
            
            case 'No'

                %create data matrix (double precision) to hold the data.

                new_data = zeros(size(data_matrix,1), (6+size(bands_colors,2)));
                new_data                                   = num2cell(new_data);
        
                io = 1;
        
            case 'Yes'
                                
                new_data = load([directory AllImageSpecs.fileSeparator 'NEW_DATA.mat']);
                new_data                                        = struct2cell(new_data);
                new_data                                                = new_data{1,1};
                
                %determine the starting iteration.
                
                double_mat   = cell2mat(new_data(:,2));
                
                io = find(double_mat == 0, 1, 'first');
                
                clear double_mat;
                
                
        end;
        
        
        
        %initialized waitbar to track progress.
        
        track_h = waitbar(0, 'Initializing Reanalysis');
        
        
        %reanalyze the cortex data for each image.
        
        for i = io:size(data_matrix,1)
            
            
            %define current image ID.
            
            current_ID = data_matrix{i,1};
            
            index = find(current_ID == '.', 1, 'last');
            
            current_ID2  = [current_ID(1:index) 'tif'];
            
            
            %record image ID.
            
            new_data{i, 1} = current_ID;
            
            
            %define the current stele radius.
            
            stele_radius = .5*calib_length*data_matrix{i,11};
            
            
            %isolate only the cortex cells.
            
            [cortex_bw, solidSegment, highlight_cortex, flag] = isolate_cortex(current_ID, current_ID2, stele_radius);
           
            
            %only reanalyze cortex data if the color coded images exist.
            
            
            switch flag
                
                case 1
            
            
                    %label all cell area objects in cortical region using function:
                    %bwlabel.

                    [L4, num_cortex_objs] = bwlabel(cortex_bw, 4);


                    %calculate the attributes of the cortex binary using the 'regionprops'
                    %function.

                    L4_regionprops = regionprops(L4, 'Area', 'Centroid', ...
                        'Perimeter', 'MajorAxisLength', 'MinorAxisLength');


                    %allocate matrix.

                    cortexData = zeros(num_cortex_objs,11);


                    %place variables in matrix.

                    cent      = cat(1, L4_regionprops.Centroid);


                    cortexData(:,1)             = cat(1, L4_regionprops.Area);
                    cortexData(:,2)                   = (1:1:(max(max(L4))))';
                    cortexData(:,5)                     = cent(:,1) - Coms(1);
                    cortexData(:,6)                     = cent(:,2) - Coms(2);    

                    [theta, rho] = cart2pol(cortexData(:,5), cortexData(:,6));
                    theta(theta < 0)                = theta(theta < 0) + 2*pi;

                    cortexData(:,3:4)                           = [theta rho];
                    cortexData(:,7)  = cat(1, L4_regionprops.MajorAxisLength);
                    cortexData(:,8)                                     = rho;
                    cortexData(:,9)  = cat(1, L4_regionprops.MinorAxisLength);



                    max_min_rad = [max(cortexData(:,4)) min(cortexData(:,4))];


                    %clear some variables from memory.

                    clear L4_regionprops cent theta rho;


                    %normalize the radius coordinate.


                    %radius measurements are indexed by inner cortex cell wall rather than 
                    %the inner most cell file (this change was made novemeber 19, 2010).



                    %load in the x-section binary image.

                    X_binary = imread([directory AllImageSpecs.fileSeparator 'X_section_binary' ...
                       AllImageSpecs.fileSeparator 'XS_binary.' current_ID]);



                    %whiten out stele area.  all you should have left is a binary cortical region.

                    X_binary(solidSegment ~= 0)          = 1;
                    X_binary(bwperim(solidSegment) == 1) = 0;    



                    %define the row and column indices of the cortical cell wall.    

                    [row_cortex_binary, col_cortex_binary] = find(X_binary == 0);


                    %normalized these coordinates with respect to the x-section center of mass.

                    col_cortex_binary = col_cortex_binary - Coms(1);
                    row_cortex_binary = row_cortex_binary - Coms(2);


                    %convert these values to polar coordinates.

                    [theta_cortex_binary, rho_cortex_binary] = cart2pol(col_cortex_binary, row_cortex_binary);

                    theta_cortex_binary(theta_cortex_binary < 0) = theta_cortex_binary(theta_cortex_binary < 0) + 2*pi;




                    %define theta interval for the normalization procedure.

                    theta = 0:(pi/45):2*pi;


                    %allocate memory for cortex thickness measurements.

                    cortex_thickness = zeros(length(theta) -1,1);



                    %for each theta interval (i.e. direction range). calculate the normalized
                    %distance between the inner and outer cortex.  this normalization will
                    %reduce the directional bias of the normalized distance calculation.  this
                    %is the way it should be done.  If one wants to the reduce the theta
                    %interaval for more accuracy then one can adjust the above variable :
                    %theta.


                    for j = 1:(length(theta) - 1)


                        %define lower bound for theta interval.

                        lower_bound = theta(j);


                        %define upper bound for theta interval.

                        upper_bound = theta(j+1); 


                        %sample attribute data from theta region.  

                        sample_index = find((cortexData(:, 3) >= lower_bound) & ...
                            (cortexData(:, 3) < upper_bound));


                        %define cell structure with theta region. 

                        cell_wall = rho_cortex_binary((theta_cortex_binary >= lower_bound) ...
                            & (theta_cortex_binary < upper_bound)); 


                        %define radius of inner-most cell wall pixel within delta theta slice.

                        min_radius = min(cell_wall); 


                        %define raduis of outer-most cell wall pixel within delta theta slice.

                        max_radius = max(cell_wall); 


                        %define the cortex thickness for each sample slice.

                        cortex_thickness(j) = max_radius - min_radius;


                        %define normalized radius for cells within theta slice.

                        cortexData(sample_index, 4) = (cortexData(sample_index, 4) - ...
                            min_radius)/(max_radius - min_radius);



                    end;




                    %calculate the overall cortex thickness for the cross-section.

                    cortex_thickness    = median(cortex_thickness);

                    new_data{i, 2} = cortex_thickness/calib_length;




                    %loop through each cortex interval and assign color code to matrix indices.

                    for j = 1:(length(bands_intervals) - 1) 


                        %define the lower and upper boundary for each cortex interval. 

                        lower_bound =     bands_intervals(j);  
                        upper_bound = bands_intervals(j + 1);  


                        %assign color tag to each object falling within the cortex interval.

                        cortexData((cortexData(:,4) >= lower_bound) &  (cortexData(:,4) < upper_bound), 11) ...
                            = bands_colors(j); 


                    end;                
            
            
            
            
            
                    %remove cortex cell area noise prior to remaining variable
                    %measurements.

                    %****************noise reduction algorithm needs some work****************%

                    non_aeren = cortex_noise_reduct(cortexData);
                    %non_aeren = cortexData;


                    %-------------------------noise reduction (end)---------------------------%            




                    %assign cortex cell count and cortical cell area to data matrix.

                    new_data{i, 3}              = size(non_aeren,1); 


                    %cortical cell area.  *****we need more accuracy********

                    new_data{i, 6} = sum(non_aeren(:,1))/calib_area;            





                    %allocate memory for cortical cell size bin image.


                    %make highlight image for color coding cell rings.

                    cortCellSize                                         = highlight_cortex;
                    cortCellSize((highlight_cortex ~= 0) & (highlight_cortex ~= 255)) = 255;


                    ObjectColors = repmat([100 190], [1 10]);


                    %loop through each interval based on the color tag and calculate the
                    %median cell size.

                    for theta_i = 1:(length(bands_intervals) - 1)  


                        %sub matrix for each radial band.

                        sample_band = non_aeren(non_aeren(:, 11) == bands_colors(theta_i), :);


                        for I = 1:size(sample_band,1)


                            %color in each object

                            cortCellSize(L4 == sample_band(I,2)) = ObjectColors(theta_i);

                        end;




                        %calculate the mean cell size for each cortex interval.

                        new_data{i, 7+theta_i} = median(sample_band(:,1))/calib_area;  


                    end;            


                    %find the first cell file ring.  this data matrix will be used to
                    %initialize the search of all proceding cell file rings as one proceeds to
                    %the outer cortex boundary.

                    initial_cf = first_cf(non_aeren);

                    TCApix                       = 1;

                    cf_mode                      = 2;


                    %calculate the cell wall thickness statistics.

                    %cw_thick_measure;



                    %new cell file count method.  currently under construction.

                    cell_file_count = cf_Isolate(highlight_cortex, non_aeren, TCApix, initial_cf, cf_mode);            

                    new_data{i,7} = cell_file_count;


                    %account for percent coverage due to aerenchyma.

                    total_lac_area = data_matrix{i,17}/data_matrix{i,7};            


                    %validate the cortex cell count.

                    bound_coords = check_cort_count(non_aeren, max_min_rad, total_lac_area, cortex_thickness);

                    new_data{i,4} = bound_coords(1,2);
                    new_data{i,5} = bound_coords(2,2);


                    %save the new data matrix to current directory.



                    percent_done = i/size(data_matrix,1);

                    waitbar(percent_done, track_h, [num2str(floor(percent_done*100), 3) ' % Complete']);

                    
                case 0
                    
                    
                    %fill in the data matrix with -1 since there is no
                    %data.
                    
                    for k = 2:size(new_data,2)
                        
                        new_data{i,k} = -1;
                        
                    end;
                    
                    
                    
                    
            end;
                                        
            save([directory AllImageSpecs.fileSeparator 'NEW_DATA'], 'new_data');

            
        end;
        
        
        %print data to filename provided by user.
            
        print_cort_data;


        waitbar(1, track_h, 'Cortex Reanalysis Complete');
        
        
        %the directory is incomplete.  terminate session.

    case 0

        %display message telling user about incomplete directory.
        
        warndlg('Directory not completed, session terminated', 'Incomplete Directory');




end;



    %print data to file.

    function print_cort_data()
        
        
        %open the file for writing purposes.

        dataOpen = fopen(file_name, 'wt');  


        %write the data column headers to the first line in the data file.


        %raw data column label headers.

        dataLabelHeader = {'Filename', 'Cortex Thickness (mm)', ...
            'Cortex Cell Count', 'Minimum Cortex Cells', 'Maximum Cortex Cells', ...
            'Cortical Cell Area', 'Cell Files'; ...
            '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ', '%s\t ',};
        
        

 
        %create empty cell to store data header information.

        cortexLabelHeader  = cell(2, size(bands_labels,2)); 


        %create empty cell to store data precision values.

        cortexPrecisHeader = cell(1, size(bands_labels,2));  



        %define cortex region headers.  

        for I = 1:size(bands_labels,2)


            %fill in the first row of the header cell array by column

            cortexLabelHeader{1,I}                   = bands_labels{1,I};


            %assign format string to each field header in the same cell array.

            
            switch I == size(bands_labels,2)
                
                case 0
            
                    cortexLabelHeader{2,I}                              = '%s\t ';


                    %place all the precision values in the data precision array.

                    cortexPrecisHeader{1,I} = ['%1.' int2str(precision+2) 'f\t ']; 

                    
                    
                case 1
                    
                    %use newline instead of tab.
                    
                    cortexLabelHeader{2,I}                               = '%s\n';


                    %place all the precision values in the data precision array.

                    cortexPrecisHeader{1,I}  = ['%1.' int2str(precision+2) 'f\n'];                     
                    

            end;
            
        end;        
        
        
        
        %concatenate all the header information

        columnHeader = [dataLabelHeader cortexLabelHeader];  


        %print the header information to the data output file (text format).

        fprintf(dataOpen, cell2mat(columnHeader(2,:)), columnHeader{1,:});  


        %close the data file for now.

        fclose(dataOpen);          
        
        
        
        %define the general precision value obtained from the calibration file.

        set_precision =    ['%1.' int2str(precision) 'f\t '];  


        rawDataPrecis = {'%s\t ', set_precision, '%1.0f\t ', '%1.0f\t ', '%1.0f\t ', ...
            set_precision, '%1.0f\t '};        
        
        
        
        
        dataPrecis = [rawDataPrecis cortexPrecisHeader]; 



        %convert to matrix.

        format_string = cell2mat(dataPrecis);  



        %define data array (double precision) containing only integer and
        %double precision variables.  this will be used to consolidate the
        %print function line below.

        numerical_data = cell2mat(new_data(:,2:end));


        %open the data file in augmentation mode.  we will write the data under the 
        %column headers now.

        dataOpen = fopen(file_name, 'a+');  


        %loop through the data rows and write the data to file.

        for i = 1:size(new_data,1) 


            %define image name, image specifications and user comments.

            imageID           = new_data{i,1}; 


            %print all data to file now.

            fprintf(dataOpen, format_string, imageID, numerical_data(i,:));  


        end;



        %close the data file.

        fclose(dataOpen);  


        %move the data file to the sub-directory : data

        movefile(file_name, [directory AllImageSpecs.fileSeparator 'DATA']);        
        
        
  
        
        
    end




end