function [cortexData, xv_data] = manual_stele_segmentation

%this function allows the user to interactively select the stele if the
%results from the automated stele detection process gave some errors.



    global    f_fig_handle; %all GUI children. 
    global   AllImageSpecs; %all image specifications.
    global     data_matrix; %data matrix.
    global time_efficiency; %time efficiency matrix.       
    global        DirSpecs; %current batch iteration.
    global    ref_axes_obj; %reference image axess.
    global   get_ref_cdata; %reference image cdata.
    global            Coms; %center of mass values.      
    global      imagePerim; %perimeter image. 
    global        X_binary; %x-section binary.
    global    solidSegment; %x-section solid (intermediate steps)
    global X_section_solid; %x-section solid.


    tic; %start the clock.


    %access temporary images from temp image directory.

    %load in x-section coded image.

    imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'XsectionCode.tif'];

    XsectionCode                        = imread(imagename); 



    %load in original raw grayscale image.

    imagename        = [cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'current_image.' AllImageSpecs.format];

    current_image                        = imread(imagename); 



    %define the lateral regions.

    ROILat                                             = X_binary;
    ROILat(ROILat ~= 0)                                   = false;
    ROILat(XsectionCode == AllImageSpecs.highlightCode(6)) = true;


    %remove any previous stele, aeren and xv coding from XsectionCode.tif.

    XsectionCode((XsectionCode ~= 255) | ...
        (XsectionCode ~= AllImageSpecs.highlightCode(6))) = 255;



    %make 3-channel rgb image to display the results from the automatic
    %stele segmentation.  the resultant image wiil be a cross-section 
    %image with a green outline of the stele region. 


    %define perimeter of stele region and it row and column coordinates.

    imagePerim          = bwperim(solidSegment);

    [row, col]          = find(imagePerim == 1);

    posVect = [(row - Coms(2)) (col - Coms(1))];



    %dilate stele perimeter by N radial units.

    imagePerim = imdilate(imagePerim, strel('disk', AllImageSpecs.PerimThick(2)));



    %define baseline channels for main image.

    get_main_cdata = zeros([AllImageSpecs.size 3], 'uint8');


    %assign grayscale x-sections pixels to red channel.

    get_main_cdata(:,:,1)                           = current_image;


    %assign grayscale x-sections pixels to green channel.

    get_main_cdata(:,:,2)                           = current_image;


    %assign grayscale x-sections pixels to blue channel.

    get_main_cdata(:,:,3)                           = current_image;



    %highlight stele perimeter the color specified by user.

    index = find(imagePerim ~= 0);



    %highlight reference image with current stele perimeter highlight.

    ref_lat = imread([cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'refCdata.tif']);

    get_ref_cdata                              = ref_lat;


    %highlight the stele perimeter using the current data.


    %assign perimeter highlight to green channel.

    get_ref_cdata(index)                                    ...
        = AllImageSpecs.refColors(6,1);


    %assign perimeter highlight to green channel.

    get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   ...
        = AllImageSpecs.refColors(6,2);



    %assign perimeter highlight to blue channel.

    get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) ...
        = AllImageSpecs.refColors(6,3);



    %set the current reference in right axes.

    set(ref_axes_obj, 'Cdata', get_ref_cdata);  


    %set the current axes to the left axes (i.e. the main image axes where the 
    %analysis is performed by the user).

    set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));
                                              cla;          


    %show the x-section image with highlighted perimeter.

    imshow(get_main_cdata);


    %display the interactive polygon.     

    XsStelepoly(posVect, 6, Coms(1), Coms(2)); 


    %disable done buttons.

    set(f_fig_handle.done_buttons(6), 'enable', 'off');


    %remove lateral from solid stele region.

    solidSegment(ROILat ~= 0) = false;


    %define stele diameter using the major and minor axis lengths.

    x_section_regions = regionprops(solidSegment, 'MajorAxisLength', 'MinorAxisLength');


    %get the major axis length vector.

    major_AL = cat(1, x_section_regions.MajorAxisLength);


    %get the minor axis length vector.

    minor_AL = cat(1, x_section_regions.MinorAxisLength);


    %concatenate these vectors.

    axis_lengths           = [major_AL minor_AL];


    %sort the  result from highest to lowest.

    axis_lengths    = sortrows(axis_lengths, -1);


    %assign stele diameter to data matrix.

    data_matrix{DirSpecs.iteration, 11}  = ((axis_lengths(1,1) + axis_lengths(1,2))/2)/AllImageSpecs.calib_length;            


    %set the left axes to the current axes and clear any visible images.

    set(gcf, 'CurrentAxes', f_fig_handle.im_axes(1));  
                                                 cla; 

    %the entire batch of images were converted to binary format in.   this change
    %took place on january 26, 2011. segment the cortex and stele separately based
    %on the results in this function.


    %solidCortex is basically the cortical region filled in with  white pixels while
    %leaving all other pixels black.  it will look like a white dougnut 
    %(assuming no laterals) against a black background.

    %define the blank solid cortex.

    solidCortex                                 = X_binary;
    solidCortex(:,:)                               = false;


    %set the cross-section pixels to white (i.e. value = 1).

    solidCortex(X_section_solid ~= 0)               = true;


    %set the stele and lateral pixels to black (i.e. value = 0).

    solidCortex((solidSegment ~= 0) | (ROILat ~= 0)) = false;



    %segment cortex. we are removing the stele and lateral from the x-section image

    cortexBinary               = X_binary; 
    cortexBinary(solidCortex == 0) = true;


    %segment stele. we are retaining only the stele region in x-section image.

    steleBinary                  = X_binary;
    steleBinary(solidSegment == 0)   = true;


    %update reference image.

    get_ref_cdata(index)                                    = current_image(index);
    get_ref_cdata((AllImageSpecs.tot_dim_pixels) + index)   = current_image(index);
    get_ref_cdata(2*(AllImageSpecs.tot_dim_pixels) + index) = current_image(index);



    %define perimeter of stele region for highlighting.

    imagePerim = bwperim(solidSegment);


    %dilate perimeter by N radial units so that user can see easier.

    imagePerim = imdilate(imagePerim, strel('disk', AllImageSpecs.PerimThick(2)));


    index                               = find(imagePerim ~= 0);


    %assign perimeter highlight to red channel.

    get_ref_cdata(index)                                      ...
        = AllImageSpecs.refColors(6,1);


    %assign perimeter highlight to green channel.

    get_ref_cdata(((AllImageSpecs.tot_dim_pixels) + index))   ...
        = AllImageSpecs.refColors(6,2);


    %assign perimeter highlight to blue channel.

    get_ref_cdata((2*(AllImageSpecs.tot_dim_pixels) + index)) ...
    = AllImageSpecs.refColors(6,3);


    set(ref_axes_obj, 'Cdata', get_ref_cdata);




    %code the stele and cortex cell wall into the coded image and save the changes.

    %color the lateral region back into x-section-code

    XsectionCode(ROILat ~= 0) = AllImageSpecs.highlightCode(6);


    %color the  solid stele and stele cell wall area.

    XsectionCode(solidSegment ~= 0) = AllImageSpecs.highlightCode(7);

    XsectionCode(steleBinary == 0)  = AllImageSpecs.highlightCode(4);


    %color the cortex cells (non xylem) and cell structure.

    XsectionCode(cortexBinary == 0) = AllImageSpecs.highlightCode(5);

    imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'XsectionCode.tif'];

                   imwrite(XsectionCode, imagename, 'tif');



    %save image data to temporary files.

    %save reference image with stele selection + lateral selection.

    imagename = [cd AllImageSpecs.fileSeparator 'temp' ...
        AllImageSpecs.fileSeparator 'ref_lat_stele.tif'];  

                   imwrite(get_ref_cdata, imagename, 'tif');    


    %_________________________________________________________________________%
    %------------------------------MEASUREMENTS-------------------------------%
    %_________________________________________________________________________%
    %------------------------------MEASUREMENTS-------------------------------%
    %_________________________________________________________________________%


    %----------------define cortex area values for data matrix----------------%            




    %define cortex cell wall area (ccwa).  we need to take the image negative of
    %the cortexBinary.

    data_matrix{DirSpecs.iteration, 6}  = bwarea(imcomplement(cortexBinary))/AllImageSpecs.calib_area; 


    %total cortex area (tca = all pixels in the cortical region).

    data_matrix{DirSpecs.iteration, 7}  = bwarea(solidCortex)/AllImageSpecs.calib_area; 





    %----------------define stele area values for data matrix-----------------%




    %define stele cell wall area. (scwa = stele cell wall area). we need to take
    %the negative of the steleBinary.

    data_matrix{DirSpecs.iteration, 9} ...
        = bwarea(imcomplement(steleBinary))/AllImageSpecs.calib_area;  


    %define total stele area (tsa = stele cell wall +  stele non-cell wall).

    data_matrix{DirSpecs.iteration, 10} ...
        = bwarea(solidSegment)/AllImageSpecs.calib_area;  


    %define the total cross-section cell wall area (xscwa = stele cell wall + cortex cell wall).        

    data_matrix{DirSpecs.iteration, 3} = data_matrix{DirSpecs.iteration, 9} + data_matrix{DirSpecs.iteration, 6};  

    time_efficiency{DirSpecs.iteration, 5} = toc;


    %----Automated aerenchyma and xylem vessel detection functions----%


    %execute automated aerenchyma detection function here.


    %start clock 

    tic; 


    %detect aerenchyma.

    cortexData = automatic_lacunae_detection(XsectionCode);  


    %stop clock and record time.  

    time_efficiency{DirSpecs.iteration, 6} = toc; 


    %execute automated xylem vessel detection function here. 


    %start clock

    tic;


    %detect meta xylem.

    xv_data = automatic_XV_detection;  


    %stop clock and record time.

    time_efficiency{DirSpecs.iteration, 7} = toc;       



            
end