function [cort_cw_thick_measure, CORTEX_THICK] = ...
    radial_cell_file_count(BLACK_ERODE, non_aeren, image_name)


%this function will count the number of radial cell files for each delta
%theta slice about the cross-section center of mass and compute an expected
%radial cell file count.


%date: March 4, 2011.


global CELL_FILE_STATS; %cell file data cell arrray.
global        DirSpecs; %structure containing current directory specifications.
global     DATA_MATRIX; %data cell array.
global              L4; %cortex object label matrix.
global X_section_solid; %solid x-section image.
global   AllImageSpecs; %image specifications.
global    solidSegment; %solid stele image.
global    f_fig_handle; %structure containing all figure children properties.




%this function will calculate the the number of cortex cell files in any
%cross section.

imagename  = [cd AllImageSpecs.fileSeparator 'TEMP' ...
    AllImageSpecs.fileSeparator 'XsectionCode.tif'];

XsectionCode                        = imread(imagename);



%remove all -1 values from label matrix.

L4(L4 == -1) = 0;




%-------------------------------------------------------------------------%

%calculate the median cell radius for each delta theta and radial interval
%in the cortical region.

%-------------------------------------------------------------------------%


    %STEP 1: MED. CELL SIZE CALCULATION
    
    
    non_aeren(non_aeren(:,3) <= 0,3) = non_aeren(non_aeren(:,3) <= 0,3) + 2*pi;
    
    
    %define the radial sampling bands and radial bandwidth used in the calculation.
    
    bands = [.1 .3 .5 .7 .9];
    bandwidth = 1/10;
    
    
    %define the angular sampling bandwidth and angular sampling intervals
    %used in the calculation.  for our case we will use delta(theta) = 15 
    %deg = .2618 rad.
    
    angular_bandwidth = .7854;
    angular_bands = 0:angular_bandwidth:2*pi;
    
    %allocate memory for data calculations.
    
    med_cort_cell_size = zeros(length(bands)*(length(angular_bands) - 1), 8);
    
    
    %loop through each delta theta interval to sample all objects in that
    %slice.
    
    count = 0;
    
    for angle_i = 1:(length(angular_bands) - 1)
    
        %define lower and upper theta boundary.
        
        lower_angle    = angular_bands(angle_i);
        
        upper_angle = angular_bands(angle_i +1);
        
        
        %define theta mid-point as the mean of the lower and upper theta
        %boundary values.
        
        target_angle = mean([lower_angle upper_angle]);
        
        
        %sample all data within theta interval between the lower and upper
        %theta boundaries.
        
        theta_sample = non_aeren((non_aeren(:,3) >= lower_angle) & ...
            (non_aeren(:,3) < upper_angle), :);
        
        
    %calculate variables for all radial bands for each delta theta interval.  
        
        for i = 1:length(bands)

            count = count + 1;
            
            %define target radius for matrix subset defintion.
            
            target_radius = bands(i);
       
            
            %define the data subset for each radial interval.
        
            sample_objects = theta_sample(((theta_sample(:,4) > ...
                (target_radius - bandwidth)) & (theta_sample(:,4) <= ...
                (target_radius + bandwidth))), [7  end]);

        
            sample_objects = mean(sample_objects,2);
        
        
            %remove sample outliers (we want to remove the salt and pepper
            %noise.)
        
            sample_mean_std = mean(sample_objects) - sqrt(std(sample_objects));
        
            sample_objects = sample_objects(sample_objects > sample_mean_std);
        
            %assign theta mid-point to data matrix.
            
            med_cort_cell_size(count,1)           = target_angle;
            
            
            %assign target radius to data matrix.
            
            med_cort_cell_size(count,2)          = target_radius;
            
            
            %assign the sample size value to the data matrix.
            
            med_cort_cell_size(count,3) = length(sample_objects);
            
            
            %only assign cell size statistics to data matrix if the current
            %sample is not empty.
            
            
            switch isempty(sample_objects)
                
                case 0
            
            
            %assign the following cell size statistical measures to the
            %data matrix: median cell size, cell size standard deviation,
            %min cell size and max cell size.
                    
            med_cort_cell_size(count,4) = median(sample_objects);
            med_cort_cell_size(count,5)  = (std(sample_objects));
            med_cort_cell_size(count,6)    = min(sample_objects);
            med_cort_cell_size(count,7)    = max(sample_objects);
            
            end;
            
            

        end;
    


    end;



    
    
    
    
%-------------------------------------------------------------------------%

%calculate the median cortex thickness for each delta theta and radial interval
%in the cortical region.

%-------------------------------------------------------------------------%

%STEP 2: MEDIAN CORTEX THICKNESS.
    
%the first few steps contribute to calculating the x and y perimeter
%coordinates for the solid cortical region involve isolating the cortical
%region from the solid cross-section image.

    %define the solid cross-section pixels.  the image (not shown in
    %analysis) should be a solid cross-section (white pixels) and
    %background(black pixels).

    XsectionCode(X_section_solid == 0)                        = 0;
    XsectionCode(XsectionCode == 5)                         = 255;
    
    XsectionCode((XsectionCode ~= 0) & (XsectionCode ~= 255)) = 0;
    


    FILLED_CORTEX      = XsectionCode; 
    
    

    
    %remove stele pixels. the image (not shown in analysis) should be a
    %solid cortical region without the stele region.  should look like a
    %doughnut give the assumption of no laterals in image.
    
    FILLED_CORTEX(solidSegment ~= 0)   = 0; 
    
    
    %convert to un-signed 8-bit int.
    
    FILLED_CORTEX = logical(FILLED_CORTEX); 
        
   
    
    %define the perimeter of the cortex cutout.
    
    FILLED_CORTEX_PERIM = bwperim(FILLED_CORTEX); 
    
    
    %find the row and column coords for perimeter cutout
    
    [row_i, col_i] = find(FILLED_CORTEX_PERIM ~= 0); 
    
    
    %find the row and column coords for the x-section solid.
    
    [row_i_xs, col_i_xs] = find(XsectionCode ~= 0);
    
    
    %calculate the cross-section center of mass for the x and y pixel
    %coordinates.
    
    row_bar = mean(row_i_xs);
    col_bar = mean(col_i_xs);
    
    
    %adjust the perimeter coords based on the cross-section center of mass
    %coordinates.
    
    row_i = row_i - row_bar;
    col_i = col_i - col_bar;
    
    
    %convert to polar coordinates.
   
    [THETA, RHO] = cart2pol(col_i, row_i);

    
    %convert -pi:pi coordinate systen to a 0:2*pi coordinate system.
    
    THETA(THETA <= 0) = THETA(THETA <= 0) + 2*pi;
    
    
    
    %calculate the median cortex thickness for each angular band interval.
    %note: the angular band intervals are the sample for steps in the
    %radial cell file calculation.
    
    
    %allocate memory for cortex thickness calculations matrix.
    
    cortex_thickness = zeros((length(angular_bands) - 1), 4);
    
    for angle_i = 1:(length(angular_bands) - 1)
        
        
        %define lower and upper theta boundary.

        lower_angle = angular_bands(angle_i);
        
        upper_angle = angular_bands(angle_i +1);
        
        
        %define theta mid-point as the mean of the lower and upper theta
        %boundary values.
        
        target_angle = mean([lower_angle upper_angle]);
        
        
        %sample all data within theta interval between the lower and upper
        %theta boundaries.
        
        theta_sample = RHO((THETA >= lower_angle) & ...
            (THETA < upper_angle), :);
        
        
        %find the inner cortical perimeter pixel radial values and outer cortical
        %perimeter pixels radial values.
        
        inner_perim_pixels = theta_sample(theta_sample < .5*(max(theta_sample)+min(theta_sample)));
        outer_perim_pixels = theta_sample(theta_sample > .5*(max(theta_sample)+min(theta_sample)));
        
        
        %define the maximum cortical thickness for each theta interval.
        %this will tell us the variation in cortical thickness 360 degrees
        %about the cross-section center of mass.
        
        min_inner_pixel_radius = min(inner_perim_pixels);
        max_outer_pixel_radius = max(outer_perim_pixels);
        
        
        %assign the cortical thickness values if such a value exists for
        %the theta interval.  the only case in which cortical thickness
        %does not exist is around lateral regions.
        
        if ((isempty(max_outer_pixel_radius) == 0) || ...
                (isempty(min_inner_pixel_radius) == 0))
        
            %assign the cortical thickness, inner boundary and outer
            %boundary radial coordinates for theta interval to data matrix.
            
            cortex_thickness(angle_i,2) = max_outer_pixel_radius - min_inner_pixel_radius;
            cortex_thickness(angle_i,3) = min_inner_pixel_radius;
            cortex_thickness(angle_i,4) = max_outer_pixel_radius;
        
        end;
        
        
        %assign theta mid-point to data matrix
        
        cortex_thickness(angle_i,1) = target_angle;
        
        
        
        
        
    end;



    %calculate the median cortex thickness.
    
    cortex_thickness = cortex_thickness(cortex_thickness(:,2) ~= 0, :);
    cortex_thickness = cortex_thickness(cortex_thickness(:,2) ~= Inf, :);
    
    
    CORTEX_THICK = median(cortex_thickness(:,2));
    

%-------------------------------------------------------------------------%

%calculate the cell wall thicknesses for each delta theta and radial interval
%in the cortical region.

%-------------------------------------------------------------------------%
    
    
    
%STEP 3: CORTEX CELL WALL THICKNESS

PROPS = regionprops(L4, 'Centroid');

CENTS = cat(1,PROPS.Centroid);

TriangleD = DelaunayTri(CENTS(:,1), CENTS(:,2));

X_vert_coord = TriangleD.X(:,1);
Y_vert_coord = TriangleD.X(:,2);

Vertex = TriangleD(:,:);

Closed_triangle = Vertex(:, [1 2 3 1])';


%interpolate triangulations.

Closed_tri_X = X_vert_coord(Closed_triangle);
Closed_tri_Y = Y_vert_coord(Closed_triangle);


%interpolate each column of data.

SEGMENT = zeros(size(L4));

vertice_matrix = [1 2; 2 3; 3 4];

for j = 1:size(Closed_tri_X,2)

    for i = 1:size(vertice_matrix,1)

        x_y_mat = [Closed_tri_X(vertice_matrix(i, :),j) Closed_tri_Y(vertice_matrix(i, :),j)];
        
        [min_row, min_col] = find(x_y_mat(:,1) == min(x_y_mat(:,1)));
        [max_row, max_col] = find(x_y_mat(:,1) == max(x_y_mat(:,1)));
        
        
            
        xo_xf_equal = isequal(x_y_mat(1,1), x_y_mat(2,1));  %are the min and max xo's different.  
        
        
        switch xo_xf_equal

        
            case 0
        
        xi = (x_y_mat(min_row,1):.1:x_y_mat(max_row,1));
    
        %use standard linearization for the y-interpolation (segment whos (x,y) = vertice_matrix(i,[1 2])).
    
        yo = x_y_mat(min_row,2); %initial y-value
        
        yf = x_y_mat(max_row,2); %final y-value
        
        xo = x_y_mat(min_row,1); %initial x-value
        
        xf = x_y_mat(max_row,1); %final y-value
        
        f_1st_order_deriv = (yf - yo)/(xf - xo); %first derivative
    
        dx = xi - xo; %change in x between two vertices.
        
        Interpolate_Y = f_1st_order_deriv.*dx + yo;
        
        
        
            case 1
        
                
        %if (xo == xf) %we have an infinite slope. adjust the y-interpolation.
            
            Interpolate_Y = min(x_y_mat(:,2)):max(x_y_mat(:,2)); %alternative y-interpolation.
            xi = Interpolate_Y*0 + min(x_y_mat(:,1)); %alternative x-interpolation.
            
        %end;
    
        %Interpolate_Y = interp1(Closed_tri_X(1:3,i), Closed_tri_Y(1:3,i), xi, 'linear');
    
        %xi2 = (floor(min(Closed_tri_X(2:4,i))):.1:floor(max(Closed_tri_X(2:4,i))));
    
        %Interpolate_Y2 = interp1(Closed_tri_X(2:4,i), Closed_tri_Y(2:4,i), xi2, 'linear');
    
        end;
    
    
        index1 = (size(L4,1)*(floor(xi) - 1)) + ...
            floor(Interpolate_Y);
    
        %index2 = (size(L4,1)*(floor(xi2(isnan(Interpolate_Y) == 0)) - 1)) + ...
            %floor(Interpolate_Y2(isnan(Interpolate_Y2) == 0));
    
    
        SEGMENT(index1) = 1;




    end;


end;
    
    




intersect_segment = zeros(size(L4));
intersect_segment((SEGMENT ~= 0) & (BLACK_ERODE == 0)) = 255;






label_intersect = bwlabel(intersect_segment);
intersect_props = regionprops(label_intersect, 'MajorAxisLength', 'Centroid');

major_axis_length = cat(1, intersect_props.MajorAxisLength);
centroid = cat(1, intersect_props.Centroid);


%[stele_row, stele_col] = find(solidSegment ~= 0);


x = centroid(:,1) - col_bar;
y = centroid(:,2) - row_bar;


[theta_cell_wall, rho] = cart2pol(x,y);

theta_cell_wall(theta_cell_wall <= 0) = theta_cell_wall(theta_cell_wall <= 0) + 2*pi;

cell_wall_segments = horzcat(theta_cell_wall, rho, major_axis_length);


    %calculate the median cell wall thickness for each angular band
    %interval.
    
    cort_cell_wall_thick = zeros(length(bands)*(length(angular_bands) - 1), 3);

    count = 0;
    
    for angle_i = 1:(length(angular_bands) - 1)
        
        
        lower_angle = angular_bands(angle_i);
        upper_angle = angular_bands(angle_i +1);
        
        target_angle = mean([lower_angle upper_angle]);
        
        theta_sample = cell_wall_segments((cell_wall_segments(:,1) >= lower_angle) & ...
            (cell_wall_segments(:,1) < upper_angle), :);
        
        
        theta_sample(:,2) = (theta_sample(:,2) - cortex_thickness(angle_i,3))/...
            cortex_thickness(angle_i,2);
        
        
        %calculate variables for all radial bands for each delta theta interval.  
        
        for i = 1:length(bands)

            count = count + 1;
            
            %define target radius for matrix subset defintion.
            
            target_radius = bands(i);
       
            
            %define the data subset for each radial interval.
        
            
            
            sample_objects = theta_sample(((theta_sample(:,2) > ...
                (target_radius - bandwidth)) & (theta_sample(:,2) <= ...
                (target_radius + bandwidth))), 3);

            
            %calculate the mean and 2 standard deviation outlier mark.
            
            switch isempty(sample_objects)
                
                case 0
                    
            
                   mean_2_std = mean(sample_objects) + 2*std(sample_objects);
            
                   sample_objects = sample_objects(sample_objects <= mean_2_std);
                   
                   median_sample_objects = median(sample_objects);
                   cort_cell_wall_thick(count,3) = median_sample_objects;

        
            
            end;
            
            cort_cell_wall_thick(count,1) = target_angle;
            cort_cell_wall_thick(count,2) = target_radius;
        



        end;


    end;


    %calculate the median, std, and range for the cortex cell wall
    %thickness.
    
    ccwt = cort_cell_wall_thick(cort_cell_wall_thick(:,3) ~= 0, 3);
    
    cort_cw_thick_measure = [median(ccwt) std(ccwt) (max(ccwt) - min(ccwt))];    

    
    


    %remove all bad data (i.e. 3rd column data entry = 0) from the data sets.
    %there is no data for these data collection runs.
    
    med_cort_cell_size = med_cort_cell_size(med_cort_cell_size(:,4) ~= 0,:);
    
    cort_cell_wall_thick = cort_cell_wall_thick(cort_cell_wall_thick(:,3) ~= 0,:);
    
    cortex_thickness = cortex_thickness(cortex_thickness(:,2) ~= 0,:);
    
    
    %next step is to filter out any bad data from the median cell size
    %calculations.
    
    %calculate the median of the median cell size calculation for all data
    %in each radial distance band.
    
    for I = 1:length(bands)
    
        sample = med_cort_cell_size(med_cort_cell_size(:,2) == bands(i), :);
        
        median_std_median = median(sample(:, 4)) - std(sample(:,4));
        
        
        %remove all data greater than the median + std.
        
        med_cort_cell_size(med_cort_cell_size(:,4) < median_std_median, :) = [];
        
    
        
    end;
    
    
    
    %run the radial cell file calculation model for all angular intervals
    %to determine the median radial cell file count.
    
    
    %allocate memory for the results from the cell file calculation model.
    
    cell_file_approx = zeros((length(angular_bands) - 1), 4);
    
    
    %allocate a cell array for the radial cell file member radial
    %coordinates for each cell file member.
    
    dx_result = cell((length(angular_bands) - 1), 1);
    
    
    
    
    
    %run the model for data within each theta interval.
    
    for angle_i = 1:(length(angular_bands) - 1)
    
        
        %define target angle for matrix indexing purposes.
        
        target_angle = cortex_thickness(angle_i,1);
        
        
        
        %-----------define the input variables for each model run---------%
        
        %the primary input variables are median cortical cell size within
        %radial distance band, cortex thickness and cortical cell wall
        %thickness within radial distance band.
        
        %define the median cortex cell size for angular interval.
        
        cell_size = med_cort_cell_size(med_cort_cell_size(:,1) == target_angle, :);
        
    
        %define the cortex thickness for angular interval.
        
        cort_thick = cortex_thickness(angle_i,:);
        
        
        %define the cell wall thickness for angular interval.
        
        cell_wall = cort_cell_wall_thick(cort_cell_wall_thick(:,1) == target_angle,:);
    
        
        %only run model if data parameters exist and we have enough data points.
        
        cw_matrix_size = size(cell_wall, 1);
        
        cs_matrix_size = size(cell_size, 1);
        
        
        %define null values for data matrix.  these values will only be
        %recorded if there are not enough parameters for the calculations.
        
        result = 0;
        dx_keep_minus = 0;
        
        
        %if conditions are met then run the model
        
        switch ((cw_matrix_size <= 2) + isempty(cort_thick) + (cs_matrix_size <= 3))
    
            case 0 %conditions are met.
                
             
                %run the model: 'model_cell_file'.  this model will
                %generate 2 output variables: hi and low cell file count
                %and cell file member position within the radial dimension
                %of the cortical regions.
                
                [result, dx_keep_minus] = model_cell_file(cell_size, cort_thick, cell_wall);
    
        end
        
        
        %assign theta mid-point to data matrix.
        
        cell_file_approx(angle_i,1) = target_angle;
        
        
        %assign cell file calcation result to data matrix.
        
        cell_file_approx(angle_i, 2:3) = result;
       
        
        %assign model run indice to data matrix.
        
        cell_file_approx(angle_i, 4) = angle_i;
        

        dx_result{angle_i,1} = [target_angle dx_keep_minus'];
        
        
    end;
    
    
    
    
    %remove all zero data.
    
    
    
    cell_file_approx((cell_file_approx(:,2) == 0) & (cell_file_approx(:,3) == 0), :) = [];
    
    
    
    %remove all data with cell file count over 40.  these are the absolute
    %outliers.
    
    cell_file_approx((cell_file_approx(:,2) >= 40) & (cell_file_approx(:,3) >= 40), :) = [];
    
    
    %remove all data with cell file count over mean + std. these are
    %highly probable outliers.
    
    mean_2_std = mean(cell_file_approx(:,3)) + std(cell_file_approx(:,3));
    
    
    cell_file_approx = cell_file_approx(cell_file_approx(:,3) <= mean_2_std, :);
    
    
    
    %calculate the median cell file count for the data matrix.
    
    
    median_cf = floor(median(cell_file_approx(:,3)) + .5);
    
    std_cf = sqrt(std(cell_file_approx(:,3)));
    
    
    pos_cf_dev = median_cf + std_cf;
    
    neg_cf_dev = median_cf - std_cf;
    
    

    
    diff_med = abs(cell_file_approx(:,3) - median_cf);
    
    target_angle_index = find(diff_med == min(diff_med));
    
    
    switch isempty(target_angle_index)
        
        case 0
    
    target_angle = cell_file_approx(target_angle_index(1), 1);
    
    
    %define the dx_result for the model run.
    
    dx_keep_minus = dx_result{cell_file_approx(target_angle_index, 4), 1};
    dx_keep_minus = dx_keep_minus(2:end);
    
    
    %define representative cortex thickness for cross-section.
    
    cort_thick = cortex_thickness(cortex_thickness(:,1) == target_angle,:);

    
            
    CORTEX_THICKNESS = cort_thick(2);

    
    
    cell_file_approx = [length(dx_keep_minus) neg_cf_dev pos_cf_dev];

    
    colors = zeros(length(dx_keep_minus), 3);



colorbank = [255 51 0; 0 200 200; 255 242 0; ...
    150 100 0; 0 238 122; 101 125 255]; 

J = 0;

for I = 1:length(dx_keep_minus)
    
    J = J + 1;
    
    colors(I,1) = colorbank(J,1);
    colors(I,2) = colorbank(J,2);
    colors(I,3) = colorbank(J,3);
    
    
    
    
    if J == size(colorbank,1)
        
        J = 0;
        
    end;
        
        
    
end;





RED_CHANNEL   = BLACK_ERODE;
GREEN_CHANNEL = BLACK_ERODE;
BLUE_CHANNEL  = BLACK_ERODE;


ALL_CHANNEL = ones(size(BLACK_ERODE,1), size(BLACK_ERODE,2),3);


cell_file_color = zeros(size(non_aeren,1),3);




CELLS_PER_FILE = zeros(5, median_cf);


dx_keep_minus = [0 dx_keep_minus];




for I = 1:(length(dx_keep_minus) - 1)
    
    lower_bound = dx_keep_minus(I)/CORTEX_THICKNESS;
    upper_bound = dx_keep_minus(I+1)/CORTEX_THICKNESS;
    
   
    
    index = find((non_aeren(:,4) > lower_bound) & (non_aeren(:,4) <= ...
        upper_bound));
    
    
    

    %CELLS_PER_FILE(1, I) = total_circum/(cell_size_file+cell_wall_file);
    
    
    %CALCULATE THE MEDIAN CELL SIZE FOR EACH CELL FILE REGION.
    
    CELLS_PER_FILE(1, I) = median(non_aeren(index,1))/(AllImageSpecs.CALIB)^2;
    
    
    %CALCULATE THE CELL SIZE STANDARD DEVIATION FOR EACH CELL FILE REGION.
    
    CELLS_PER_FILE(2, I) = std(non_aeren(index,1))/(AllImageSpecs.CALIB)^2;
    
    
    %CALCULATE THE RADIAL DISTANCES FOR EACH RADIAL CELL FILE.
    
    CELLS_PER_FILE(3, I) = dx_keep_minus(I+1)/(AllImageSpecs.CALIB);
    
    

    
    

    cell_file_color(index,1) = colors(I,1);
    cell_file_color(index,2) = colors(I,2);
    cell_file_color(index,3) = colors(I,3);

    
    
    
    
end;
   


%calculate the number of cell files in the cortical region based on the
%number of cells per circular cell rings and distance from the
%cross-section center of mass.



%we need to calculate the the median cell size (area) for each cell file
%member.


%we need to take the sum of total cortical area (i.e. TCA) and cortex cell wall
%area (CCWA) and divide by the total cell file area to calculate the total
%number of cell files in the cortex.




for J = 1:size(non_aeren(:,1))
    
    RED_CHANNEL(L4 == non_aeren(J,2)) = cell_file_color(J,1);
    GREEN_CHANNEL(L4 == non_aeren(J,2)) = cell_file_color(J,2);
    BLUE_CHANNEL(L4 == non_aeren(J,2)) = cell_file_color(J,3);
    



end;



ALL_CHANNEL(:,:,1) = RED_CHANNEL;
ALL_CHANNEL(:,:,2) = GREEN_CHANNEL;
ALL_CHANNEL(:,:,3) = BLUE_CHANNEL;




ALL_CHANNEL = uint8(ALL_CHANNEL);

                
%WRITE THE IMAGE TO FILE WITH THE PREVIOUSLY DEFINED FILE NAME.
                
  
save([cd '/TEMP/CF_IMAGE'], 'ALL_CHANNEL');

                
%DEFINE OUTPUT DIRECTORY FOR IMAGE DATA.

Image_output_directory = ['Image_Output' AllImageSpecs.fileSeparator image_name];  
                
%define filename for highlighted cross-section image and print it to file.
                
imagename = [cd AllImageSpecs.fileSeparator Image_output_directory  AllImageSpecs.fileSeparator 'CORTEX_CELL_FILES.' image_name]; 
imwrite(ALL_CHANNEL, imagename, AllImageSpecs.format);  
    


    %display the cell file count in GUI.
        
    set(f_fig_handle.IMAGE_NAME(2), 'String', ['RCFC: ', ...
        int2str(cell_file_approx(1))]);
    
        case 1
            
        cell_file_approx = [0 0 0];
        
        CELLS_PER_FILE = [0; 0; 0];
        
        set(f_fig_handle.IMAGE_NAME(2), 'String', 'RCFC: N/A');
    
    end;
    
    
    
    
    
    
    %place variables in cell file matrix.
    
%PLACE ALL THE CELL FILE STATISTICS IN THE CELL FILES MATRIX
   
%place the cell file count (median, lower and upper bounds) into the cell array.

    CELL_FILE_STATS{DirSpecs.BATCH_ITER,1} = cell_file_approx(1);
    CELL_FILE_STATS{DirSpecs.BATCH_ITER,2} = cell_file_approx(2);
    CELL_FILE_STATS{DirSpecs.BATCH_ITER,3} = cell_file_approx(3);

    
    
for CI = 1:size(CELLS_PER_FILE,2)

    
    %place the median cell size for each cell file into the cell array.
    
    CELL_FILE_STATS{DirSpecs.BATCH_ITER,CI+3} = CELLS_PER_FILE(1,CI);
    
    
    %place the cell size standard deviation for each cell file into the
    %cell array.

    CELL_FILE_STATS{DirSpecs.BATCH_ITER,CI+23} = CELLS_PER_FILE(2,CI);
    
    
    %place the radial position value for each cell file into the
    %cell array.
   
    CELL_FILE_STATS{DirSpecs.BATCH_ITER,CI+43} = CELLS_PER_FILE(3,CI);
    

end;    
    
    
    DATA_MATRIX{DirSpecs.BATCH_ITER, 20}             = cell_file_approx(1); %CELLS PER FILES.
  
    
    


end